package org.rcisoft.business.bslschedule.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.Result;
import org.rcisoft.core.result.ResultServiceEnums;
import org.rcisoft.core.model.PersistModel;
import org.rcisoft.core.constant.MessageConstant;
import org.rcisoft.common.controller.PaginationController;
import org.rcisoft.core.util.UserUtil;
import org.rcisoft.common.model.GridModel;
import org.rcisoft.core.exception.ServiceException;
import javax.validation.Valid;


import org.rcisoft.business.bslschedule.entity.BSlSchedule;
import org.rcisoft.business.bslschedule.service.BSlScheduleService;
import springfox.documentation.annotations.ApiIgnore;

import java.text.ParseException;
import java.util.List;

/**
* Created by  on 2018-5-2 16:39:34.
*/
@RestController
@RequestMapping("bslschedule")
public class BSlScheduleController extends PaginationController<BSlSchedule> {

    @Autowired
    private BSlScheduleService bSlScheduleServiceImpl;


    @ApiOperation(value="添加", notes="添加")
    //@ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PostMapping(value = "/add")
    public Result add(@Valid BSlSchedule bSlSchedule, BindingResult bindingResult) {
        bSlSchedule.setToken(getToken());
        PersistModel data = bSlScheduleServiceImpl.save(bSlSchedule);
        return Result.builder(data,
            MessageConstant.MESSAGE_ALERT_SUCCESS,
            MessageConstant.MESSAGE_ALERT_ERROR,
        bSlSchedule);
    }

    @ApiOperation(value="逻辑删除", notes="逻辑删除")
    @ApiImplicitParams({@ApiImplicitParam(name = "id", value = "id", required = false, dataType = "varchar")})
    @DeleteMapping("/delete/{id:\\w+}")
    public Result delete(@PathVariable String id) {
        BSlSchedule bSlSchedule = new BSlSchedule();
        bSlSchedule.setBusinessId(id);
        bSlSchedule.setToken(getToken());
        PersistModel data = bSlScheduleServiceImpl.remove(bSlSchedule);
        return Result.builder(data,
            MessageConstant.MESSAGE_ALERT_SUCCESS,
            MessageConstant.MESSAGE_ALERT_ERROR,
        id);
    }

    @ApiOperation(value="修改", notes="修改")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{id:\\w+}")
    public Result update(@Valid BSlSchedule bSlSchedule, BindingResult bindingResult) {
        bSlSchedule.setToken(getToken());
        PersistModel data = bSlScheduleServiceImpl.merge(bSlSchedule);
        return Result.builder(data,
            MessageConstant.MESSAGE_ALERT_SUCCESS,
            MessageConstant.MESSAGE_ALERT_ERROR,
        bSlSchedule);
    }

    @ApiOperation(value="查看单 ", notes="查看单 ")
    @GetMapping("/detail/{id:\\w+}")
    public Result detail(@PathVariable String id) {
        return Result.builder(new PersistModel(1),
            MessageConstant.MESSAGE_ALERT_SUCCESS,
            MessageConstant.MESSAGE_ALERT_ERROR,
        bSlScheduleServiceImpl.findById(id));
    }

    @ApiOperation(value="查看  集合", notes="查看单  集合")
    @GetMapping(value = "/queryBSlScheduleByPagination")
    public GridModel listByPagination(BSlSchedule bSlSchedule) {
        bSlSchedule.setCreateBy(UserUtil.getUserInfoProp(getToken(),UserUtil.USER_ID));
        bSlScheduleServiceImpl.findAllByPagination(getPaginationUtility(), bSlSchedule);
        return getGridModelResponse();
    }

    @ApiOperation(value="查周视图", notes="查周视图")
    @ApiImplicitParams({@ApiImplicitParam(name = "week", value = "周次", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "subAgencyId", value = "subAgencyId", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "termCode", value = "学期编号", required = true, dataType = "varchar")})
    @GetMapping(value = "/queryBSlScheduleMore")
    public Result listMore(String week,String subAgencyId,String termCode) throws ParseException {
        return Result.builder(new PersistModel(1),
                MessageConstant.MESSAGE_ALERT_SUCCESS,
                MessageConstant.MESSAGE_ALERT_ERROR,
                bSlScheduleServiceImpl.queryMoreBSlSchedules(week,subAgencyId,termCode));
    }
}
